@@ -5,7 +5,8 @@ const zigbeeHerdsmanConverters = require('zigbee-herdsman-converters');
 
 
 for (const line of text.split('\n')) {
-    const model = zigbeeHerdsmanConverters.devices.find((d) => d.model === line);
+    const [modelNumber, user] = line.split(',').map((t) => t.trim());
+    const model = zigbeeHerdsmanConverters.devices.find((d) => d.model === modelNumber);
     if (!model) throw new Error(`${line} does not exist`);
-    console.log(`- \`${line}\` ${model.vendor} ${model.description}`);
+    console.log(`- \`${modelNumber}\` ${model.vendor} ${model.description} (${user})`);
 }
